hiphp for control php websites
==========================
A package for controlling a php-based website.

Installation
============

.. code::

    pip install hiphp

Usage
=====
.. code:: python

    from hiphp import hiphp

    hiphp("<PASSWORD>","http://LINK/TO/YOUR/PHP/FILE").run()

.. begin changelog

Changelog
=========

0.0.4
-----
- Fix bugs.

0.0.2
-----
- Fix bugs.
- Add help list.
- Add Executing from files.

0.0.1
-----
- First public release.

.. end changelog
